@@ -791,6 +791,32 @@ class TestUpdate(test_base.NodeTest):
         self.assertFalse(mock_warn.called)
         self.assertFalse(self.ironic.port.list.called)
 
+    @mock.patch.object(node_cache.LOG, 'warning', autospec=True)
+    def test_create_ports_not_update_pxe(self, mock_warn):
+        CONF.set_override('update_pxe_enabled', False, 'processing')
+        ports = [
+            'mac2',
+            {'mac': 'mac3', 'client_id': '42', 'pxe': False},
+            {'mac': 'mac4', 'pxe': True}
+        ]
+
+        self.node_info.create_ports(ports)
+        self.assertEqual({'mac0', 'mac1', 'mac2', 'mac3', 'mac4'},
+                         set(self.node_info.ports()))
+
+        create_calls = [
+            mock.call(node_uuid=self.uuid, address='mac2', extra={},
+                      is_pxe_enabled=True),
+            mock.call(node_uuid=self.uuid, address='mac3',
+                      extra={'client-id': '42'}, is_pxe_enabled=True),
+            mock.call(node_uuid=self.uuid, address='mac4', extra={},
+                      is_pxe_enabled=True),
+        ]
+        self.assertEqual(create_calls, self.ironic.create_port.call_args_list)
+        # No conflicts - cache was not cleared - no calls to port.list
+        self.assertFalse(mock_warn.called)
+        self.assertFalse(self.ironic.port.list.called)
+
     @mock.patch.object(node_cache.LOG, 'info', autospec=True)
     def test__create_port(self, mock_info):
         uuid = uuidutils.generate_uuid()
@@ -1285,6 +1311,17 @@ class TestStartIntrospection(test_base.NodeTest):
                                self.node_info.uuid)
         self.assertFalse(add_node_mock.called)
 
+    @prepare_mocks
+    def test_ensure_start_on_error(self, fsm_event_mock,
+                                   add_node_mock):
+        def side_effect(*args):
+            self.node_info._state = istate.States.error
+
+        fsm_event_mock.side_effect = side_effect
+        node_cache.start_introspection(self.node.uuid)
+        add_node_mock.assert_called_once_with(self.node_info.uuid,
+                                              istate.States.starting)
+
 
 class TestIntrospectionDataDbStore(test_base.NodeTest):
     def setUp(self):
